@@ -1,5 +1,6 @@
 from setuptools import Extension
 from setuptools.command.build_py import build_py as build_py_orig
+from setuptools.command.bdist_egg import bdist_egg as bdist_egg_by_orig
 from Cython.Build import cythonize
 import os
 
@@ -22,7 +23,7 @@ class build_py(build_py_orig):
 
 
 def get_bdist_egg(setup_py):
-    class bdist_egg:
+    class bdist_egg(bdist_egg_by_orig):
         def run(self):
             if os.environ.get('NO_CLEAR_ARTIPY') == "1":
                 return
@@ -33,6 +34,7 @@ def get_bdist_egg(setup_py):
                     for fname in os.listdir(root):
                         fname.endswith('.c')
                         os.remove(fname)
+            bdist_egg_by_orig.run(self)
 
     return bdist_egg
 
